Examples
========

.. toctree::
    :glob:
    :hidden:
    
    example_airfoil_in_open_jet_beamforming
    example_airfoil_in_open_jet_steering_vectors
    example_airfoil_in_open_jet_cmf
    example_rotating_point_source
    example_3D_beamforming

.. list-table::
    :widths: 30 70
    :class: borderless

    * - :doc:`example_airfoil_in_open_jet_beamforming`

      - Demonstrates different features of Acoular using measured data from a wind tunnel experiment on trailing edge noise.
        
    * - :doc:`example_airfoil_in_open_jet_steering_vectors`

      - Demonstrates different steering vectors in Acoular and CSM diagonal removal.

    * - :doc:`example_airfoil_in_open_jet_cmf`

      - Demonstrates the CMF method with different optimization schemes.

    * - :doc:`example_rotating_point_source`

      - Demonstrates a simple approach to beamforming on a rotating source.

    * - :doc:`example_3D_beamforming`

      - Demonstrates a 3D beamforming setup.
